# rabity
<!---

[![License: MIT](https://img.shields.io/badge/License-MIT-lightgrey.svg?style=flat-square)](https://opensource.org/licenses/MIT)



[![pipeline status](https://gitlab.com/ahnaf-zamil/zenora/badges/master/pipeline.svg)](https://gitlab.com/ahnaf-zamil/zenora/-/commits/master)<br/>
-->



[![Pypi](https://img.shields.io/pypi/v/rabity.svg?style=flat-square)](https://pypi.org/project/rabity/)
[![Docs](https://img.shields.io/badge/Docs-Click-blue?style=flat-square&logo=rabity.svg
)](https://rabity.gitbook.io/)

A Flask based python lib

## What is rabity
Rabity is a **FLASK** based Python lib for making Working Websites With:

- Speed

- Custom html File
And more
## How To Install
### 1- Install with PIP:
```bash
pip install rabity
```
## Plan to add
- Fully Login system for free

- Login with **google and other**
